==> rizin-0.4.1-1.0-i686.pkg.tar.zst: usr/lib/cmake/rz_crypto/rz_cryptoConfig.cmake <==
################################################################################
#
# This module provides the following imported targets, if found:
#
#  rz_crypto::rz_crypto
#
# This file is intended to be consumed by clients who wish to use rz_crypto from CMake.
# The recommended way to use find this module is using `find_package(Rizin COMPONENTS ...)`.
#
# Provides the following variables
# rz_crypto_FOUND        - Flag for indicating that rz_crypto package has been found
# rz_crypto_VERSION      - Version of rz_crypto
# rz_crypto_INCLUDE_DIRS - Directories to include
# rz_crypto_LIBRARY      - Path to the single library that this module represents, without dependencies
# rz_crypto_LIBRARIES    - Libraries to link
# rz_crypto_LIBRARY_DIRS - Library directories to search for link libraries
# rz_crypto_PLUGINDIR    - Directory where plugins are placed, without the prefix part
#
################################################################################

set(RIZIN_MODULE_PREFIXED rz_crypto)
set(rz_crypto_VERSION 0.4.1)

# FIXME: workaround for https://github.com/mesonbuild/meson/issues/9702 (see https://github.com/rizinorg/rizin/issues/2102)
get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../.." ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

set(rz_crypto_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/librz" "${PACKAGE_PREFIX_DIR}/include/librz/sdb")
set_and_check(rz_crypto_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
find_library(rz_crypto_LIBRARY NAMES rz_crypto HINTS "${rz_crypto_LIBRARY_DIRS}" NO_DEFAULT_PATH REQUIRED)
set(rz_crypto_LIBRARIES "${rz_crypto_LIBRARY}")
set(_rz_crypto_DEPENDENCIES rz_util)
set(rz_crypto_PLUGINDIR lib/rizin/plugins)

include(CMakeFindDependencyMacro)
get_filename_component(_rizin_cmake_path "${CMAKE_CURRENT_LIST_DIR}/.." ABSOLUTE)
set(_rz_crypto_DEPENDENCY_TARGETS)
foreach(_module_dep ${_rz_crypto_DEPENDENCIES})
  if (NOT ${_module_dep}_FOUND)
    find_dependency(${_module_dep} PATHS ${_rizin_cmake_path})
  endif()

  if (NOT ${_module_dep}_FOUND)
    set(rz_crypto_FOUND False)
    return()
  endif()

  list(APPEND rz_crypto_INCLUDE_DIRS "${${_module_dep}_INCLUDE_DIRS}")
  list(APPEND rz_crypto_LIBRARIES "${${_module_dep}_LIBRARIES}")
  list(APPEND _rz_crypto_DEPENDENCY_TARGETS "${_module_dep}::${_module_dep}")
endforeach()

list(REMOVE_DUPLICATES rz_crypto_INCLUDE_DIRS)
list(REMOVE_DUPLICATES rz_crypto_LIBRARIES)

if(NOT TARGET rz_crypto::rz_crypto)
  add_library(rz_crypto::rz_crypto SHARED IMPORTED)
  target_link_libraries(rz_crypto::rz_crypto INTERFACE ${_rz_crypto_DEPENDENCY_TARGETS})
  set_target_properties(rz_crypto::rz_crypto PROPERTIES
    INTERFACE_INCLUDE_DIRECTORIES "${rz_crypto_INCLUDE_DIRS}")
  set_target_properties(rz_crypto::rz_crypto PROPERTIES
    IMPORTED_LOCATION "${rz_crypto_LIBRARY}")
endif()
set(rz_crypto_TARGET rz_crypto::rz_crypto)

==> rizin-0.7.3-3.0-i686.pkg.tar.zst: usr/lib/cmake/rz_crypto/rz_cryptoConfig.cmake <==
################################################################################
#
# This module provides the following imported targets, if found:
#
#  rz_crypto::rz_crypto
#
# This file is intended to be consumed by clients who wish to use rz_crypto from CMake.
# The recommended way to use find this module is using `find_package(Rizin COMPONENTS ...)`.
#
# Provides the following variables
# rz_crypto_FOUND        - Flag for indicating that rz_crypto package has been found
# rz_crypto_VERSION      - Version of rz_crypto
# rz_crypto_INCLUDE_DIRS - Directories to include
# rz_crypto_LIBRARY      - Path to the single library that this module represents, without dependencies
# rz_crypto_LIBRARIES    - Libraries to link
# rz_crypto_LIBRARY_DIRS - Library directories to search for link libraries
# rz_crypto_PLUGINDIR    - Directory where plugins are placed, without the prefix part
#
################################################################################

set(RIZIN_MODULE_PREFIXED rz_crypto)
set(rz_crypto_VERSION 0.7.3)

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../.." ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

set(rz_crypto_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/librz" "${PACKAGE_PREFIX_DIR}/include/librz/sdb")
set_and_check(rz_crypto_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
find_library(rz_crypto_LIBRARY NAMES rz_crypto HINTS "${rz_crypto_LIBRARY_DIRS}" NO_DEFAULT_PATH REQUIRED)
set(rz_crypto_LIBRARIES "${rz_crypto_LIBRARY}")
set(_rz_crypto_DEPENDENCIES rz_util)
set(rz_crypto_PLUGINDIR lib/rizin/plugins)

include(CMakeFindDependencyMacro)
get_filename_component(_rizin_cmake_path "${CMAKE_CURRENT_LIST_DIR}/.." ABSOLUTE)
set(_rz_crypto_DEPENDENCY_TARGETS)
foreach(_module_dep ${_rz_crypto_DEPENDENCIES})
  if (NOT ${_module_dep}_FOUND)
    find_dependency(${_module_dep} PATHS ${_rizin_cmake_path} NO_DEFAULT_PATH)
  endif()

  if (NOT ${_module_dep}_FOUND)
    set(rz_crypto_FOUND False)
    return()
  endif()

  list(APPEND rz_crypto_INCLUDE_DIRS "${${_module_dep}_INCLUDE_DIRS}")
  list(APPEND rz_crypto_LIBRARIES "${${_module_dep}_LIBRARIES}")
  list(APPEND _rz_crypto_DEPENDENCY_TARGETS "${_module_dep}::${_module_dep}")
endforeach()

list(REMOVE_DUPLICATES rz_crypto_INCLUDE_DIRS)
list(REMOVE_DUPLICATES rz_crypto_LIBRARIES)

if(NOT TARGET rz_crypto::rz_crypto)
  add_library(rz_crypto::rz_crypto SHARED IMPORTED)
  target_link_libraries(rz_crypto::rz_crypto INTERFACE ${_rz_crypto_DEPENDENCY_TARGETS})
  set_target_properties(rz_crypto::rz_crypto PROPERTIES
    INTERFACE_INCLUDE_DIRECTORIES "${rz_crypto_INCLUDE_DIRS}")
  set_target_properties(rz_crypto::rz_crypto PROPERTIES
    IMPORTED_LOCATION "${rz_crypto_LIBRARY}")
endif()
set(rz_crypto_TARGET rz_crypto::rz_crypto)
